@@ -1,7 +1,4 @@
-
 from spectrum import *
-from spectrum import cholesky
-from cholesky import *
 from numpy.testing import assert_array_almost_equal
 import numpy
 
