@@ -1,6 +1,6 @@
 from spectrum import *
-from spectrum import yulewalker 
-from yulewalker import *
+#from spectrum import yulewalker 
+#from yulewalker import *
 from pylab import linspace, plot, savefig, axis, log10
 from nose.tools import assert_almost_equal
 
